{ config, pkgs, ... }:

{
  imports =
    [
      ./hardware-configuration.nix
      ../../configuration/proxmox-vm
      ../../configuration/hydra-build-machine

      ./build-machines.nix
      ./hydra.nix
      ./nix-cache.nix
    ];

  boot.loader.grub.enable = true;
  boot.loader.grub.device = "/dev/vda";
  
  boot.binfmt.emulatedSystems = [
    "armv6l-linux"
    "armv7l-linux"
    "aarch64-linux"
  ];

  networking.hostName = "hydra-1";

  networking.useDHCP = false;
  networking.interfaces.ens18.ipv6.addresses = [ { address = "2001:638:904:ffcb::a"; prefixLength = 64; } ];
  networking.interfaces.ens19.ipv4.addresses = [ { address = "192.168.10.36"; prefixLength = 24; } ];
  networking.defaultGateway6 = { address = "2001:638:904:ffcb::1"; interface = "ens18"; };
  networking.defaultGateway = { address = "192.168.10.1"; interface = "ens19"; };
  networking.nameservers = [ "2001:638:904:ffcc::3" "2001:638:904:ffcc::4" "141.24.40.3" "141.24.40.4" ];

  services.nginx.enable = true;

  networking.firewall.allowedTCPPorts = [ 80 443 ];

  clerie.monitoring = {
    enable = true;
    id = "210";
    pubkey = "bA7b+vRlfvbGma74+Tz+FHGcRKPe+oAOfXmuqDR4+Sc=";
  };

  system.stateVersion = "22.11";
}
